@@ -2,13 +2,14 @@ import abc
 import re
 from dataclasses import dataclass
 from pathlib import Path
-from typing import Dict, List, Optional, Pattern, Tuple, Union
+from typing import Any, Dict, List, Optional, Pattern, Tuple, Union
 
 import cli_ui as ui
 import schema
 import tomlkit
 from tomlkit.toml_document import TOMLDocument
 
+from tbump.action import Action
 from tbump.error import Error
 from tbump.hooks import HOOKS_CLASSES, Hook
 
@@ -33,6 +34,7 @@ class Config:
 
     git_tag_template: str
     git_message_template: str
+    atomic_push: bool
 
     files: List[File]
     hooks: List[Hook]
@@ -41,25 +43,46 @@ class Config:
     github_url: Optional[str]
 
 
-class ConfigFile(metaclass=abc.ABCMeta):
+class ConfigFileUpdater(Action, metaclass=abc.ABCMeta):
     """Base class representing a config file"""
 
-    def __init__(self, path: Path, doc: TOMLDocument):
+    def __init__(self, project_path: Path, path: Path, doc: TOMLDocument):
+        self.project_path = project_path
         self.path = path
         self.doc = doc
 
-    def save(self) -> None:
-        as_string = tomlkit.dumps(self.doc)
-        self.path.write_text(as_string)
+    @property
+    def relative_path(self) -> Path:
+        return self.path.relative_to(self.project_path)
+
+    def print_self(self) -> None:
+        from tbump.cli import print_diff
+
+        old_text = self.path.read_text()
+        new_text = tomlkit.dumps(self.doc)
+
+        lineno = 1
+        for old_line, new_line in zip(old_text.splitlines(), new_text.splitlines()):
+            if old_line != new_line:
+                print_diff(
+                    str(self.relative_path),
+                    lineno + 1,
+                    old_line.strip(),
+                    new_line.strip(),
+                )
+            lineno += 1
+
+    def do(self) -> None:
+        new_text = tomlkit.dumps(self.doc)
+        self.path.write_text(new_text)
 
     @abc.abstractmethod
     def get_parsed(self) -> dict:
         """Return a plain dictionary, suitable for validation
         by the `schema` library
         """
-        pass
 
-    @abc.abstractclassmethod
+    @abc.abstractmethod
     def set_new_version(self, version: str) -> None:
         pass
 
@@ -71,40 +94,47 @@ class ConfigFile(metaclass=abc.ABCMeta):
         return res
 
 
-class TbumpTomlConfig(ConfigFile):
+class TbumpTomlUpdater(ConfigFileUpdater):
     """Represent config inside a tbump.toml file"""
 
-    def __init__(self, path: Path, doc: TOMLDocument):
-        super().__init__(path, doc)
+    def __init__(self, project_path: Path, path: Path, doc: TOMLDocument):
+        super().__init__(project_path, path, doc)
 
     def get_parsed(self) -> dict:
         # Document -> dict
         return self.doc.value
 
-    def set_new_version(self, new_version: str) -> None:
-        self.doc["version"]["current"] = new_version  # type: ignore
-        self.save()
+    def set_new_version(self, version: str) -> None:
+        self.doc["version"]["current"] = version  # type: ignore[index]
 
 
-class PyprojectConfig(ConfigFile):
+class PyprojectUpdater(ConfigFileUpdater):
     """Represent a config inside a pyproject.toml file,
     under the [tool.tbump] key
     """
 
-    def __init__(self, path: Path, doc: TOMLDocument):
-        super().__init__(path, doc)
+    def __init__(self, project_path: Path, path: Path, doc: TOMLDocument):
+        super().__init__(project_path, path, doc)
+
+    @staticmethod
+    def unwrap_data(data: Any) -> Any:
+        if hasattr(data, "unwrap") and callable(data.unwrap):
+            return data.unwrap()
+        else:
+            return data
 
     def get_parsed(self) -> dict:
         try:
-            tool_section = self.doc["tool"]["tbump"].value  # type: ignore
+            tool_section = PyprojectUpdater.unwrap_data(
+                self.doc["tool"]["tbump"]  # type: ignore[index]
+            )
         except KeyError as e:
             raise InvalidConfig(parse_error=e)
 
-        return tool_section.value  # type: ignore
+        return tool_section  # type: ignore[no-any-return]
 
     def set_new_version(self, new_version: str) -> None:
-        self.doc["tool"]["tbump"]["version"]["current"] = new_version  # type: ignore
-        self.save()
+        self.doc["tool"]["tbump"]["version"]["current"] = new_version  # type: ignore[index]
 
 
 def validate_template(name: str, pattern: str, value: str) -> None:
@@ -167,7 +197,11 @@ def validate_basic_schema(config: dict) -> None:
     tbump_schema = schema.Schema(
         {
             "version": {"current": str, "regex": schema.Use(validate_re)},
-            "git": {"message_template": str, "tag_template": str},
+            "git": {
+                "message_template": str,
+                "tag_template": str,
+                schema.Optional("atomic_push"): bool,
+            },
             "file": [file_schema],
             schema.Optional("field"): [field_schema],
             schema.Optional("hook"): [hook_schema],  # retro-compat
@@ -212,12 +246,12 @@ def validate_config(cfg: Config) -> None:
 
 def get_config_file(
     project_path: Path, *, specified_config_path: Optional[Path] = None
-) -> ConfigFile:
+) -> ConfigFileUpdater:
     try:
         config_type, config_path = _get_config_path_and_type(
             project_path, specified_config_path
         )
-        res = _get_config_file(config_type, config_path)
+        res = _get_config_file(project_path, config_type, config_path)
         # Make sure config is correct before returning it
         res.get_config()
         return res
@@ -244,13 +278,15 @@ def _get_config_path_and_type(
     raise ConfigNotFound(project_path)
 
 
-def _get_config_file(config_type: str, config_path: Path) -> ConfigFile:
+def _get_config_file(
+    project_path: Path, config_type: str, config_path: Path
+) -> ConfigFileUpdater:
     if config_type == "tbump.toml":
         doc = tomlkit.loads(config_path.read_text())
-        return TbumpTomlConfig(config_path, doc)
+        return TbumpTomlUpdater(project_path, config_path, doc)
     elif config_type == "pyproject.toml":
         doc = tomlkit.loads(config_path.read_text())
-        return PyprojectConfig(config_path, doc)
+        return PyprojectUpdater(project_path, config_path, doc)
     raise ValueError("unknown config_type: {config_type}")
 
 
@@ -259,6 +295,7 @@ def from_parsed_config(parsed: dict) -> Config:
     current_version = parsed["version"]["current"]
     git_message_template = parsed["git"]["message_template"]
     git_tag_template = parsed["git"]["tag_template"]
+    atomic_push = parsed["git"].get("atomic_push", True)
     version_regex = re.compile(parsed["version"]["regex"], re.VERBOSE)
     files = []
     for file_dict in parsed["file"]:
@@ -290,6 +327,7 @@ def from_parsed_config(parsed: dict) -> Config:
         version_regex=version_regex,
         git_message_template=git_message_template,
         git_tag_template=git_tag_template,
+        atomic_push=atomic_push,
         fields=fields,
         files=files,
         hooks=hooks,
@@ -306,7 +344,7 @@ class ConfigNotFound(Error):
         self.project_path = project_path
 
     def print_error(self) -> None:
-        ui.error("No configuration for tbump fond in", self.project_path)
+        ui.error("No configuration for tbump found in", self.project_path)
         ui.info("Please run `tbump init` to create a tbump.toml file")
         ui.info("Or add a [tool.tbump] section in the pyproject.toml file")
 
