@@ -3,6 +3,7 @@ from typing import List, Sequence
 import cli_ui as ui
 
 from tbump.action import Action
+from tbump.config import ConfigFileUpdater
 from tbump.file_bumper import FileBumper
 from tbump.git_bumper import GitBumper
 from tbump.hooks import HooksRunner
@@ -15,7 +16,7 @@ class ActionGroup:
         desc: str,
         actions: Sequence[Action],
         *,
-        should_enumerate: bool = False
+        should_enumerate: bool = False,
     ):
         self.should_enumerate = should_enumerate
         self.desc = desc
@@ -25,9 +26,9 @@ class ActionGroup:
     def print_group(self, dry_run: bool = False) -> None:
         if not self.actions:
             return
-        if dry_run:
+        if dry_run and self.dry_run_desc:
             ui.info_2(self.dry_run_desc)
-        else:
+        if not dry_run and self.desc:
             ui.info_2(self.desc)
         for i, action in enumerate(self.actions):
             if self.should_enumerate:
@@ -40,10 +41,23 @@ class ActionGroup:
 
 
 class Executor:
-    def __init__(self, new_version: str, file_bumper: FileBumper):
+    def __init__(
+        self,
+        new_version: str,
+        file_bumper: FileBumper,
+        config_file: ConfigFileUpdater,
+    ):
         self.new_version = new_version
         self.work: List[ActionGroup] = []
 
+        update_config_group = ActionGroup(
+            f"Would update current version in {config_file.relative_path}",
+            "Updating current version",
+            [config_file],
+            should_enumerate=False,
+        )
+        self.work.append(update_config_group)
+
         patches = ActionGroup(
             "Would patch these files",
             "Patching files",
