@@ -1,26 +1,25 @@
 import glob
 import re
+from dataclasses import dataclass
 from pathlib import Path
 from typing import Dict, List, Optional, Pattern
 
-import attr
 import cli_ui as ui
 
-import tbump
-import tbump.action
-import tbump.config
-import tbump.git
+from tbump.action import Action
+from tbump.config import Config, File, get_config_file
+from tbump.error import Error
 
 
-@attr.s
+@dataclass
 class ChangeRequest:
-    src: str = attr.ib()
-    old_string: str = attr.ib()
-    new_string: str = attr.ib()
-    search: Optional[str] = attr.ib(default=None)
+    src: str
+    old_string: str
+    new_string: str
+    search: Optional[str] = None
 
 
-class Patch(tbump.action.Action):
+class Patch(Action):
     def __init__(
         self, working_path: Path, src: str, lineno: int, old_line: str, new_line: str
     ):
@@ -32,22 +31,11 @@ class Patch(tbump.action.Action):
         self.new_line = new_line
 
     def print_self(self) -> None:
-        # fmt: off
-        ui.info(
-            ui.red, "- ", ui.reset,
-            ui.bold, self.src, ":", ui.reset,
-            ui.darkgray, self.lineno + 1, ui.reset,
-            " ", ui.red, self.old_line.strip(),
-            sep="",
+        from tbump.cli import print_diff
+
+        print_diff(
+            self.src, self.lineno + 1, self.old_line.strip(), self.new_line.strip()
         )
-        ui.info(
-            ui.green, "+ ", ui.reset,
-            ui.bold, self.src, ":", ui.reset,
-            ui.darkgray, self.lineno + 1, ui.reset,
-            " ", ui.green, self.new_line.strip(),
-            sep="",
-        )
-        # fmt: on
 
     def do(self) -> None:
         self.apply()
@@ -69,7 +57,7 @@ class Patch(tbump.action.Action):
         file_path.write_bytes(text)
 
 
-class BadSubstitution(tbump.Error):
+class BadSubstitution(Error):
     def __init__(
         self,
         *,
@@ -108,7 +96,7 @@ class BadSubstitution(tbump.Error):
         ui.error(*message, end="", sep="")
 
 
-class InvalidVersion(tbump.Error):
+class InvalidVersion(Error):
     def __init__(self, *, version: str, regex: Pattern[str]):
         super().__init__()
         self.version = version
@@ -118,7 +106,7 @@ class InvalidVersion(tbump.Error):
         ui.error("Could not parse", self.version, "as a valid version string")
 
 
-class SourceFileNotFound(tbump.Error):
+class SourceFileNotFound(Error):
     def __init__(self, *, src: str):
         super().__init__()
         self.src = src
@@ -127,7 +115,7 @@ class SourceFileNotFound(tbump.Error):
         ui.error(self.src, "does not exist")
 
 
-class CurrentVersionNotFound(tbump.Error):
+class CurrentVersionNotFound(Error):
     def __init__(self, *, src: str, current_version_string: str):
         super().__init__()
         self.src = src
@@ -158,31 +146,29 @@ def on_version_containing_none(
 
 
 class FileBumper:
-    def __init__(self, working_path: Path):
+    def __init__(self, working_path: Path, config: Config):
         self.working_path = working_path
-        self.files: List[tbump.config.File] = []
-        self.version_regex = re.compile(".")
-        self.current_version = ""
-        self.current_groups: Dict[str, str] = {}
+        self.files = config.files
+        self.fields = config.fields
+        self.version_regex = config.version_regex
+        self.current_version = config.current_version
+
+        self.current_groups = self.parse_version(self.current_version)
         self.new_version = ""
         self.new_groups: Dict[str, str] = {}
-        self.config_file: Optional[tbump.config.ConfigFile] = None
 
     def parse_version(self, version: str) -> Dict[str, str]:
         assert self.version_regex
-        match = self.version_regex.fullmatch(version)
-        if match is None:
+        regex_match = self.version_regex.fullmatch(version)
+        if regex_match is None:
             raise InvalidVersion(version=version, regex=self.version_regex)
-        return match.groupdict()
+        groups = regex_match.groupdict()
 
-    def set_config_file(self, config_file: tbump.config.ConfigFile) -> None:
-        self.config_file = config_file
-        config = config_file.get_config()
-        self.files = config.files
-        self.check_files_exist()
-        self.version_regex = config.version_regex
-        self.current_version = config.current_version
-        self.current_groups = self.parse_version(self.current_version)
+        # apply default fields from config
+        for field in self.fields:
+            if groups.get(field.name) is None:
+                groups[field.name] = str(field.default)
+        return groups
 
     def check_files_exist(self) -> None:
         assert self.files
@@ -235,21 +221,13 @@ class FileBumper:
         # When bumping files in a project, we need to bump:
         #  * every file listed in the config file
         #  * and the `current_version` value in tbump's config file
-        assert self.config_file
         change_requests = []
         for file in self.files:
             change_request = self.compute_change_request_for_file(file)
             change_requests.append(change_request)
-        rel_path = self.config_file.path.relative_to(self.working_path)
-        config_file_change = ChangeRequest(
-            str(rel_path),
-            self.current_version,
-            self.new_version,
-        )
-        change_requests.append(config_file_change)
         return change_requests
 
-    def compute_change_request_for_file(self, file: tbump.config.File) -> ChangeRequest:
+    def compute_change_request_for_file(self, file: File) -> ChangeRequest:
         if file.version_template:
             current_version = file.version_template.format(**self.current_groups)
             if "None" in current_version:
@@ -282,9 +260,9 @@ class FileBumper:
 
 def bump_files(new_version: str, repo_path: Optional[Path] = None) -> None:
     repo_path = repo_path or Path(".")
-    bumper = FileBumper(repo_path)
-    config_file = tbump.config.get_config_file(repo_path)
-    bumper.set_config_file(config_file)
+    config_file = get_config_file(repo_path)
+    bumper = FileBumper(repo_path, config_file.get_config())
+    bumper.check_files_exist()
     patches = bumper.get_patches(new_version=new_version)
     n = len(patches)
     for i, patch in enumerate(patches):
