@@ -4,10 +4,13 @@ from typing import List, Optional, Tuple
 
 import cli_ui as ui
 
-import tbump
+from tbump.error import Error
+
+_GIT_COMMANDS = []
+_RECORD = False
 
 
-class GitError(tbump.Error):
+class GitError(Error):
     pass
 
 
@@ -37,6 +40,8 @@ def run_git(working_path: Path, *cmd: str, verbose: bool = False) -> None:
     Raise GitCommandError if return code is non-zero.
     """
     cmd_list = list(cmd)
+    if _RECORD:
+        _GIT_COMMANDS.append(cmd_list)
     if verbose:
         print_git_command(cmd_list)
     git_cmd = list(cmd)
@@ -63,7 +68,7 @@ def run_git_captured(
     options["stderr"] = subprocess.STDOUT
 
     ui.debug(ui.lightgray, working_path, "$", ui.reset, *git_cmd)
-    process = subprocess.Popen(git_cmd, cwd=working_path, **options)  # type: ignore
+    process = subprocess.Popen(git_cmd, cwd=working_path, **options)  # type: ignore[call-overload]
     output, _ = process.communicate()
     output = output.decode("utf-8")
     if output.endswith("\n"):
