@@ -4,11 +4,11 @@ from typing import List, Optional
 
 import cli_ui as ui
 
-import tbump
-import tbump.action
+from tbump.action import Action
+from tbump.error import Error
 
 
-class Hook(tbump.action.Action):
+class Hook(Action):
     def __init__(self, name: str, cmd: str):
         super().__init__()
         self.working_path: Optional[Path] = None
@@ -43,7 +43,7 @@ HOOKS_CLASSES = {
 }
 
 
-class HookError(tbump.Error):
+class HookError(Error):
     def __init__(self, *, name: str, cmd: str, rc: int):
         super().__init__()
         self.cmd = cmd
@@ -69,7 +69,7 @@ class HooksRunner:
         return self._get_hooks_for_new_version_by_type(new_version, "before_commit")
 
     def get_after_hooks(self, new_version: str) -> List[Hook]:
-        if "push" in self.operations:
+        if "push_tag" in self.operations or "push_commit" in self.operations:
             return self._get_hooks_for_new_version_by_type(new_version, "after_push")
         else:
             return []
