@@ -2,15 +2,15 @@ from pathlib import Path
 
 import pytest
 
-import tbump.file_bumper
+from tbump.config import get_config_file
+from tbump.file_bumper import BadSubstitution, CurrentVersionNotFound, FileBumper, Patch
 from tbump.test.conftest import file_contains
 
 
 def test_file_bumper_simple(test_repo: Path) -> None:
-    bumper = tbump.file_bumper.FileBumper(test_repo)
-    config_file = tbump.config.get_config_file(test_repo)
+    bumper = _bumper_for(test_repo)
     assert bumper.working_path == test_repo
-    bumper.set_config_file(config_file)
+
     patches = bumper.get_patches(new_version="1.2.41-alpha-2")
     for patch in patches:
         patch.apply()
@@ -26,7 +26,7 @@ def test_patcher_preserve_endings(tmp_path: Path) -> None:
     foo_txt = tmp_path / "foo.txt"
     old_contents = b"line 1\r\nv=42\r\nline3\r\n"
     foo_txt.write_bytes(old_contents)
-    patch = tbump.file_bumper.Patch(tmp_path, "foo.txt", 1, "v=42", "v=43")
+    patch = Patch(tmp_path, "foo.txt", 1, "v=42", "v=43")
     patch.apply()
     actual_contents = foo_txt.read_bytes()
     expected_contents = old_contents.replace(b"42", b"43")
@@ -34,15 +34,13 @@ def test_patcher_preserve_endings(tmp_path: Path) -> None:
 
 
 def test_file_bumper_preserve_endings(test_repo: Path) -> None:
-    bumper = tbump.file_bumper.FileBumper(test_repo)
-    config_file = tbump.config.get_config_file(test_repo)
+    bumper = _bumper_for(test_repo)
     package_json = test_repo / "package.json"
 
     # Make sure package.json contain CRLF line endings
     lines = package_json.read_text().splitlines(keepends=False)
     package_json.write_bytes(b"\r\n".join([x.encode() for x in lines]))
 
-    bumper.set_config_file(config_file)
     patches = bumper.get_patches(new_version="1.2.41-alpha-2")
     for patch in patches:
         patch.apply()
@@ -83,10 +81,8 @@ def test_looking_for_empty_groups(tmp_path: Path) -> None:
         version = "1.2"
         """
     )
-    config_file = tbump.config.get_config_file(tmp_path)
-    bumper = tbump.file_bumper.FileBumper(tmp_path)
-    bumper.set_config_file(config_file)
-    with pytest.raises(tbump.file_bumper.BadSubstitution) as e:
+    bumper = _bumper_for(tmp_path)
+    with pytest.raises(BadSubstitution) as e:
         bumper.get_patches(new_version="1.3.1")
     assert e.value.src == "foo"
     assert e.value.groups == {"major": "1", "minor": "2", "patch": None}
@@ -110,11 +106,9 @@ def test_current_version_not_found(tmp_path: Path) -> None:
     )
     version_txt_path = tmp_path / "version.txt"
     version_txt_path.write_text("nope")
-    config_file = tbump.config.get_config_file(tmp_path)
+    bumper = _bumper_for(tmp_path)
 
-    bumper = tbump.file_bumper.FileBumper(tmp_path)
-    bumper.set_config_file(config_file)
-    with pytest.raises(tbump.file_bumper.CurrentVersionNotFound) as e:
+    with pytest.raises(CurrentVersionNotFound) as e:
         bumper.get_patches(new_version="1.3.1")
     assert e.value.src == "version.txt"
 
@@ -152,10 +146,8 @@ def test_replacing_with_empty_groups(tmp_path: Path) -> None:
         """
     )
 
-    bumper = tbump.file_bumper.FileBumper(tmp_path)
-    config_file = tbump.config.get_config_file(tmp_path)
-    bumper.set_config_file(config_file)
-    with pytest.raises(tbump.file_bumper.BadSubstitution) as e:
+    bumper = _bumper_for(tmp_path)
+    with pytest.raises(BadSubstitution) as e:
         bumper.get_patches(new_version="1.3")
     assert e.value.groups == {"major": "1", "minor": "3", "patch": None}
 
@@ -199,12 +191,15 @@ def test_changing_same_file_twice(tmp_path: Path) -> None:
         #define PUBLIC_VERSION "1.2"
         """
     )
-    bumper = tbump.file_bumper.FileBumper(tmp_path)
-    config_file = tbump.config.get_config_file(tmp_path)
-    bumper.set_config_file(config_file)
+    bumper = _bumper_for(tmp_path)
     patches = bumper.get_patches(new_version="1.3.0")
     for patch in patches:
         patch.do()
 
     assert file_contains(tmp_path / foo_c, '#define FULL_VERSION "1.3.0"')
     assert file_contains(tmp_path / foo_c, '#define PUBLIC_VERSION "1.3"')
+
+
+def _bumper_for(working_path: Path) -> FileBumper:
+    config_file = get_config_file(working_path)
+    return FileBumper(working_path, config_file.get_config())
